import { IsInt, IsNotEmpty, IsString } from 'class-validator';
import { getConnectionManager } from 'typeorm';
import { RunnerOrganisationNotFoundError } from '../../errors/RunnerOrganisationErrors';
import { RunnerOrganisation } from '../entities/RunnerOrganisation';
import { RunnerTeam } from '../entities/RunnerTeam';

export class CreateRunnerTeam {
    /**
     * The teams's name.
     */
    @IsString()
    @IsNotEmpty()
    name: string;

    /**
     * The team's parent group (organisation).
     */
    @IsInt()
    @IsNotEmpty()
    parentId: number

    /**
     * Creates a RunnerTeam entity from this.
     */
    public async toRunnerTeam(): Promise<RunnerTeam> {
        let newRunnerTeam: RunnerTeam = new RunnerTeam();

        newRunnerTeam.name = this.name;
        newRunnerTeam.parentGroup = await getConnectionManager().get().getRepository(RunnerOrganisation).findOne({ id: this.parentId });
        if (!newRunnerTeam.parentGroup) {
            throw new RunnerOrganisationNotFoundError();
        }

        return newRunnerTeam;
    }
}